@@ -87,24 +87,26 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import cloudcomponents.cdk_secret_key
-import constructs
+import cloudcomponents.cdk_secret_key as _cloudcomponents_cdk_secret_key_a12c7701
+import constructs as _constructs_77d1e7e8
 
 
 class GithubWebhook(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-github-webhook.GithubWebhook",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[builtins.str],
-        github_api_token: typing.Union[builtins.str, cloudcomponents.cdk_secret_key.SecretKey],
+        github_api_token: typing.Union[builtins.str, _cloudcomponents_cdk_secret_key_a12c7701.SecretKey],
         github_repo_url: builtins.str,
         payload_url: builtins.str,
         log_level: typing.Optional[builtins.str] = None,
@@ -118,6 +120,10 @@ class GithubWebhook(
         :param payload_url: The URL to which the payloads will be delivered.
         :param log_level: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9fea15c4d53a91e8ff98163c995dadfd911357466ce9365a13fe0b4a6caafadb)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GithubWebhookProps(
             events=events,
             github_api_token=github_api_token,
@@ -145,7 +151,7 @@ class GithubWebhookProps:
         self,
         *,
         events: typing.Sequence[builtins.str],
-        github_api_token: typing.Union[builtins.str, cloudcomponents.cdk_secret_key.SecretKey],
+        github_api_token: typing.Union[builtins.str, _cloudcomponents_cdk_secret_key_a12c7701.SecretKey],
         github_repo_url: builtins.str,
         payload_url: builtins.str,
         log_level: typing.Optional[builtins.str] = None,
@@ -157,7 +163,14 @@ class GithubWebhookProps:
         :param payload_url: The URL to which the payloads will be delivered.
         :param log_level: -
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4764619dba203fad2b8bc2903124d361eacb9addb3213354c5e0463a047171a4)
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument github_api_token", value=github_api_token, expected_type=type_hints["github_api_token"])
+            check_type(argname="argument github_repo_url", value=github_repo_url, expected_type=type_hints["github_repo_url"])
+            check_type(argname="argument payload_url", value=payload_url, expected_type=type_hints["payload_url"])
+            check_type(argname="argument log_level", value=log_level, expected_type=type_hints["log_level"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "events": events,
             "github_api_token": github_api_token,
             "github_repo_url": github_repo_url,
@@ -179,11 +192,11 @@ class GithubWebhookProps:
     @builtins.property
     def github_api_token(
         self,
-    ) -> typing.Union[builtins.str, cloudcomponents.cdk_secret_key.SecretKey]:
+    ) -> typing.Union[builtins.str, _cloudcomponents_cdk_secret_key_a12c7701.SecretKey]:
         '''The OAuth access token.'''
         result = self._values.get("github_api_token")
         assert result is not None, "Required property 'github_api_token' is missing"
-        return typing.cast(typing.Union[builtins.str, cloudcomponents.cdk_secret_key.SecretKey], result)
+        return typing.cast(typing.Union[builtins.str, _cloudcomponents_cdk_secret_key_a12c7701.SecretKey], result)
 
     @builtins.property
     def github_repo_url(self) -> builtins.str:
@@ -222,3 +235,27 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__9fea15c4d53a91e8ff98163c995dadfd911357466ce9365a13fe0b4a6caafadb(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    events: typing.Sequence[builtins.str],
+    github_api_token: typing.Union[builtins.str, _cloudcomponents_cdk_secret_key_a12c7701.SecretKey],
+    github_repo_url: builtins.str,
+    payload_url: builtins.str,
+    log_level: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4764619dba203fad2b8bc2903124d361eacb9addb3213354c5e0463a047171a4(
+    *,
+    events: typing.Sequence[builtins.str],
+    github_api_token: typing.Union[builtins.str, _cloudcomponents_cdk_secret_key_a12c7701.SecretKey],
+    github_repo_url: builtins.str,
+    payload_url: builtins.str,
+    log_level: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
